      program savg4lpc
c
c  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
c  *              P R O G R A N :  S A V G                           *
c  *                                                                 *
c  *                   (S) TRESS    (AV) ERA  (G)  E                 *
c  *       FOR A (4)-(L)ayer grid with a 90 deg (P)ly (C)rack        *
c  *                                                                 *
c  *                TYPE-II LAMINATE [0/90/45/-45]s                  *
c  *                                                                 *
c  *     CALCULATES THE AVERAGE STRESS ALONG A SET OF ELEMENTS       *
c  *                                                                 *
c  *      1. SIGMA-Z & SIGMA-HZ JUST ABOVE (Z/T=0.766)               *
c  *         BUT PARALLEL TO THE 0/90 INTERFACE                      *
c  *                                                                 *
C  *      2. SIGMA-H ALONG H=0 THRU THE 0 DEG PLY FROM THE CRACK     *
C  *         CRACK TIP (Z/T=0.75) TO THE SURFACE (Z/T=1.0)           *
c  *                                                                 *
c  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
C
      common shm(1146),szm(1146),shzm(1146)
      common sht(1146),szt(1146),shzt(1146)
      common shw(1146),szw(1146),shzw(1146)
      common h(17),sah(3,17)
      common z(17),saz(3,17), sahz(3,17)
C 
C   ASSIGN TAPE NO.S 3,4,5/6,7,8,9 TO INPUT/OUTPUT FILES RESPECTIVELY 
C
      OPEN(3,FILE='lfemi4lpc_mechstress.out',STATUS='OLD',ERR=8888)
      OPEN(4,FILE='lfemi4lpc_thermstress.out',STATUS='OLD',ERR=8888)
      OPEN(5,FILE='lfemi4lpc_moiststress.out',STATUS='OLD',ERR=8888)
      OPEN(6,FILE='savg_stress4lpc.out',STATUS='UNKNOWN',ERR=8888)
      OPEN(7,FILE='data1.dat',STATUS='UNKNOWN',ERR=8888)
      OPEN(8,FILE='data2.dat',STATUS='UNKNOWN',ERR=8888)
      OPEN(9,FILE='data3.dat',STATUS='UNKNOWN',ERR=8888)
c
      ielem=1146
c
      do 9 i=1,ielem
      read(3,10)snm,shm(i),szm(i),shzm(i),snzm,snhm
      read(4,10)snt,sht(i),szt(i),shzt(i),snzt,snht
    9 read(5,10)snw,shw(i),szw(i),shzw(i),snzw,snhw
   10 format(5x,6(1x,e12.5))
c
c       CALCULATING POINTS ALONG THE NONDIMENSIONAL X/T COORDINATES
c
      h(1)=0.0
      h(2)=0.00625
      h(3)=0.0125
      h(4)=0.01875
      h(5)=0.03125
c
c Average stresses just above (Z/T=0.766) & parallel to 0/90 interface 
c
c       MECH STRESSES
      saz(1,1)= (szm(138)+szm(139))/2.
      saz(1,2)= (szm(136)+szm(137)+szm(138)+szm(139)
     *          +szm(140)+szm(141)+szm(142)+szm(143))/8.0
      saz(1,3)= (szm(142)+szm(143)+szm(144)+szm(145))/4.0
      saz(1,4)=((szm(144)+szm(145))/2.
     *         +(szm(146)+szm(147))/2.
     *          +szm(148)+szm(149))/4.0
      saz(1,5)= (szm(122)+szm(123)+szm(125)+szm(126))/4.0
c
      sahz(1,1)= (shzm(138)+shzm(139))/2.
      sahz(1,2)= (shzm(136)+shzm(137)+shzm(138)+shzm(139)
     *           +shzm(140)+shzm(141)+shzm(142)+shzm(143))/8.0
      sahz(1,3)= (shzm(142)+shzm(143)+shzm(144)+shzm(145))/4.0
      sahz(1,4)=((shzm(144)+shzm(145))/2.
     *          +(shzm(146)+shzm(147))/2.
     *           +shzm(148)+shzm(149))/4.0
      sahz(1,5)= (shzm(122)+shzm(123)+shzm(125)+shzm(126))/4.0
c
c       MECH+THERM STRESSES
      saz(2,1)= saz(1,1)+(szt(138)+szt(139))/2.
      saz(2,2)= saz(1,2)+(szt(136)+szt(137)+szt(138)+szt(139)
     *                   +szt(140)+szt(141)+szt(142)+szt(143))/8.0
      saz(2,3)= saz(1,3)+(szt(142)+szt(143)+szt(144)+szt(145))/4.0
      saz(2,4)=saz(1,4)+((szt(144)+szt(145))/2.
     *                  +(szt(146)+szt(147))/2.
     *                   +szt(148)+szt(149))/4.0
      saz(2,5)= saz(1,5)+(szt(122)+szt(123)+szt(125)+szm(126))/4.0
c
      sahz(2,1)= sahz(1,1)+(shzt(138)+shzt(139))/2.
      sahz(2,2)= sahz(1,2)+(shzt(136)+shzt(137)+shzt(138)+shzt(139)
     *                     +shzt(140)+shzt(141)+shzt(142)+shzt(143))/8.0
      sahz(2,3)= sahz(1,3)+(shzt(142)+shzt(143)+shzt(144)+shzt(145))/4.0
      sahz(2,4)=sahz(1,4)+((shzt(144)+shzt(145))/2.
     *                    +(shzt(146)+shzt(147))/2.
     *                     +shzt(148)+shzt(149))/4.0
      sahz(2,5)= sahz(1,5)+(shzt(122)+shzt(123)+shzt(125)+shzt(126))/4.0
c
c       MECH+THERM+MOIST STRESSES
      saz(3,1)= saz(2,1)+(szw(138)+szw(139))/2.
      saz(3,2)= saz(2,2)+(szw(136)+szw(137)+szw(138)+szw(139)
     *                   +szw(140)+szw(141)+szw(142)+szw(143))/8.0
      saz(3,3)= saz(2,3)+(szw(142)+szw(143)+szw(144)+szw(145))/4.0
      saz(3,4)=saz(2,4)+((szw(144)+szw(145))/2.
     *                  +(szw(146)+szw(147))/2.
     *                   +szw(148)+szw(149))/4.0
      saz(3,5)= saz(2,5)+(szw(122)+szw(123)+szw(125)+szw(126))/4.0
c
      sahz(3,1)= sahz(2,1)+(shzw(138)+shzw(139))/2.
      sahz(3,2)= sahz(2,2)+(shzw(136)+shzw(137)+shzw(138)+shzw(139)
     *                     +shzw(140)+shzw(141)+shzw(142)+shzw(143))/8.0
      sahz(3,3)= sahz(2,3)+(shzw(142)+shzw(143)+shzw(144)+shzw(145))/4.0
      sahz(3,4)=sahz(2,4)+((shzw(144)+shzw(145))/2.
     *                    +(shzw(146)+shzw(147))/2.
     *                     +shzw(148)+shzw(149))/4.0
      sahz(3,5)= sahz(2,5)+(shzw(122)+shzw(123)+shzw(125)+shzw(126))/4.0
c
c       CALCULATING POINTS ALONG THE NONDIMENSIONAL Z/T COORDINATES
c
      z(1)=0.753125
      z(2)=0.759375
      z(3)=0.765625
      z(4)=0.770835
      z(5)=0.78125
      z(6)=0.791667
      z(7)=0.8125
      z(8)=0.85
      z(9)=0.9
      z(10)=0.9375
      z(11)=0.9625
      z(12)=0.9875
c
c   Average sigma-y stresses thru the 0 degree ply along the z-axis at
c   x=0 from the crack tip (Z/T=0.75) up to the top surface (Z/T=1.0)
c 
c       MECH STRESSES
      sah(1,1)=(shm(138)+shm(139))/2.
      sah(1,2)=(shm(132)+shm(133))/2.
      sah(1,3)= shm(110)
      sah(1,4)= shm(112)
      sah(1,5)= shm(90)
      sah(1,6)= shm(92)
      sah(1,7)= shm(66)
      sah(1,8)= shm(51)
      sah(1,9)= shm(43)
      sah(1,10)=shm(26)
      sah(1,11)=shm(18)
      sah(1,12)=shm(2)
c
c       MECH+THERM STRESSES
      sah(2,1)= sah(1,1)+(sht(138)+sht(139))/2.
      sah(2,2)= sah(1,2)+(sht(132)+sht(133))/2.
      sah(2,3)= sah(1,3) +sht(110)
      sah(2,4)= sah(1,4) +sht(112)
      sah(2,5)= sah(1,5) +sht(90)
      sah(2,6)= sah(1,6) +sht(92)
      sah(2,7)= sah(1,7) +sht(66)
      sah(2,8)= sah(1,8) +sht(51)
      sah(2,9)= sah(1,9) +sht(43)
      sah(2,10)=sah(1,10)+sht(26)
      sah(2,11)=sah(1,11)+sht(18)
      sah(2,12)=sah(1,12)+sht(2)
c
c       MECH+THERM+MOIST STRESSES
      sah(3,1)= sah(2,1)+(shw(138)+shw(139))/2.
      sah(3,2)= sah(2,2)+(shw(132)+shw(133))/2.
      sah(3,3)= sah(2,3) +shw(110)
      sah(3,4)= sah(2,4) +shw(112)
      sah(3,5)= sah(2,5) +shw(90)
      sah(3,6)= sah(2,6) +shw(92)
      sah(3,7)= sah(2,7) +shw(66)
      sah(3,8)= sah(2,8) +shw(51)
      sah(3,9)= sah(2,9) +shw(43)
      sah(3,10)=sah(2,10)+shw(26)
      sah(3,11)=sah(2,11)+shw(18)
      sah(3,12)=sah(2,12)+shw(2)
c
c       Write results to files for plotting
c
      write(6,210)
  210 FORMAT(1X,'SIGMA-Z STRESS DISTR. JUST ABOVE 0/90 INTERFACE',
     *' (Z/T=0.766)',/,
     *' H/T POSITION    MECH    MECH+THERM  MECH+THERM+MOIST')
      do 211 i=1,5
      WRITE(7,215)h(i),saz(1,i),saz(2,i),saz(3,i)
  211 WRITE(6,215)h(i),saz(1,i),saz(2,i),saz(3,i)
  215 FORMAT(5(1X,E11.4))
c
      WRITE(6,220)
  220 FORMAT(/,1X,'SIGMA-YZ STRESS DISTR. JUST ABOVE 0/90 INTERFACE'
     *' (Z/T=0.766)',/,
     *' H/T POSITION    MECH    MECH+THERM  MECH+THERM+MOIST')
      do 221 i=1,5
      WRITE(8,215)h(i),sahz(1,i),sahz(2,i),sahz(3,i)
  221 WRITE(6,215)h(i),sahz(1,i),sahz(2,i),sahz(3,i)
c
      WRITE(6,230)
  230 FORMAT(/,1X,'SIGMA-Y STRESS DISTR. THRU THE 0 DEG PLY AT H=0'
     *,/,' Z/T POSITION    MECH    MECH+THERM  MECH+THERM+MOIST')
      do 231 i=1,12
      WRITE(9,215)z(i),sah(1,i),sah(2,i),sah(3,i)
  231 WRITE(6,215)z(i),sah(1,i),sah(2,i),sah(3,i)
C
 8888 STOP
      END
